# myfy

Opinionated Python framework with modularity, ergonomics, and power.

Meta-package that provides:
- myfy-core (kernel, DI, config)
- myfy-cli (CLI tools)

Optional modules via extras:
- `myfy[web]` - HTTP/ASGI support

See the [main README](../../README.md) for full documentation.
